const jwt = require('jsonwebtoken');
const User = require('../models/User');

const auth = async (req, res, next) => {
    try {
        const token = req.header('Authorization').replace('Bearer ', '');
        const decoded = jwt.verify(token, process.env.JWT_SECRET || 'your-secret-key');
        const user = await User.findById(decoded.id);

        if (!user) {
            throw new Error('用户不存在');
        }

        req.token = token;
        req.user = user;
        next();
    } catch (error) {
        console.error('认证失败:', error);
        res.status(401).json({ message: '请先登录' });
    }
};

const admin = (req, res, next) => {
    if (req.user && req.user.role === 'admin') {
        next();
    } else {
        res.status(401).json({ message: '未授权，需要管理员权限' });
    }
};

module.exports = { auth, admin }; 